@@ -1,17 +1,13 @@
 package Finance::Bank::ID::Base;
 
 our $DATE = '2017-07-20'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.48'; # VERSION
 
 use 5.010;
 use Moo;
 use Log::ger;
 
 use Data::Dmp;
-use Data::Rmap qw(:all);
-use DateTime;
-use Finance::BankUtils::ID::Mechanize;
-use YAML::Syck qw(LoadFile DumpFile);
 
 has mech        => (is => 'rw');
 has username    => (is => 'rw');
@@ -60,6 +56,8 @@ sub BUILD {
 }
 
 sub _set_default_mech {
+    require Finance::BankUtils::ID::Mechanize;
+
     my ($self) = @_;
     $self->mech(
         Finance::BankUtils::ID::Mechanize->new(
@@ -90,12 +88,14 @@ sub _req {
     eval {
         if ($self->mode eq 'simulation' &&
                 $self->save_dir && (-f $self->save_dir . "/$opts->{id}.yaml")) {
+            require YAML::Syck;
             $Finance::BankUtils::ID::Mechanize::saved_resp =
-                LoadFile($self->save_dir . "/$opts->{id}.yaml");
+                YAML::Syck::LoadFile($self->save_dir . "/$opts->{id}.yaml");
         }
         $mech->$meth(@$args);
         if ($self->save_dir && $self->mode ne 'simulation') {
-            DumpFile($self->save_dir . "/$opts->{id}.yaml", $mech->response);
+            require YAML::Syck;
+            YAML::Syck::DumpFile($self->save_dir . "/$opts->{id}.yaml", $mech->response);
         }
     };
     my $evalerr = $@;
@@ -248,10 +248,11 @@ sub parse_statement {
     unless ($opts{return_datetime_obj} // 1) {
         # $_[0]{seen} = {} is a trick to allow multiple places which mention the
         # same object to be converted (defeat circular checking)
-        rmap_ref {
+        require Data::Rmap;
+        Data::Rmap::rmap_ref(sub {
             $_[0]{seen} = {};
             $_ = $self->_fmtdt($_) if UNIVERSAL::isa($_, "DateTime");
-        } $stmt;
+        }, $stmt);
     }
 
     [$status, $error, $stmt];
@@ -272,7 +273,7 @@ Finance::Bank::ID::Base - Base class for Finance::Bank::ID::BCA etc
 
 =head1 VERSION
 
-This document describes version 0.47 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2017-07-20.
+This document describes version 0.48 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2017-07-20.
 
 =head1 SYNOPSIS
 
